@@ -41,10 +41,10 @@ given_when_actions = [
 then_actions = [
     ActionName('assert url of site', attribute_needed=False),
     ActionName('assert title of site', attribute_needed=False),
-    ActionName('assert input is disabled', attribute_needed=False),
     ActionName('assert input is not visible', attribute_needed=False),
     ActionName('assert input is visible', attribute_needed=False),
-    ActionName('assert element has certain text', attribute_needed=False)
+    ActionName('assert element has certain text', attribute_needed=False),
+    ActionName('assert element contains text', attribute_needed=False)
 ]
 actions = given_when_actions
 
