@@ -1,10 +1,12 @@
 import PySimpleGUI as sg
 from shared_info.constants import ERROR_PNG, OK_PNG
+from object_collections_to_string import *
 
 
 def save_changed(window, todo_actions):
     index = window['-ACTION-LIST-'].get_indexes()
     new_xpath = window['-XPATH-INPUT-'].get()
+    new_attribute = window['-HELPER-INPUT-'].get()
     if len(index) == 0:
         sg.popup_notify('Nothing selected in actions', icon=ERROR_PNG, title='Not permitted')
         return
@@ -15,4 +17,7 @@ def save_changed(window, todo_actions):
         sg.popup_notify('Selected action doesn\' include xpath', icon=ERROR_PNG, title='Not permitted')
 
     todo_action.xpath = new_xpath
-    sg.popup_notify('Saved given xpath to selected action', icon=OK_PNG, title='Saved xpath')
+    todo_action.attribute = new_attribute
+    window['-ACTION-LIST-'].update(convert_collection_to_string_using_method(collection=todo_actions,
+                                                                             method_name='format_for_todo_listbox'))
+    sg.popup_notify('Saved attributes to selected action', icon=OK_PNG, title='Saved xpath')
