@@ -6,8 +6,8 @@ def pick_tag_in_actions(window, todo_actions):
 
     if len(todo_actions) != 0:
         selected_tag = todo_actions[index[0]]
-        if selected_tag.whole_html is not None:
-            window['-TAG-DESCRIPTION-'].update(selected_tag.whole_html.prettify())
+        if selected_tag.element_html is not None:
+            window['-TAG-DESCRIPTION-'].update(selected_tag.element_html.prettify())
             window['-XPATH-INPUT-'].update(selected_tag.xpath)
         else:
             window['-TAG-DESCRIPTION-'].update('Current action does not have any tag')
