@@ -16,7 +16,7 @@ def create_new_action_file():
         f.write('from behave import *\n')
     with open(f'{os.getcwd()}/steps/new_steps.py', "w") as f:
         f.write('from behave import *\n')
-    print("Created new action file!")
+    print("Created files for generating actions and plans :D!")
 
 
 def copy_behave_environment_file():
